import requests

from shared import OKOBAU_URL, parse_epd_list, get_compliance_id


def get_epds(search: dict[str, str] | None, limit=10) -> dict:
    """Get EPDs from Ökobau"""

    response = requests.get(
        f"{OKOBAU_URL}/processes?"
        f"format=json&pageSize={limit}"
        f"{'&search=true&' + '&'.join([f'{key}={value}' for key, value in search.items()]) if search else ''}"
    )
    response.raise_for_status()
    data = response.json()

    print(f"Retrieved {data.get('pageSize')} EPDs out of {data.get('totalCount')} from Ökobau\n")

    return data


def search_epds(search: dict[str, str] | None):
    """Search Ökobau for EPDs containing the search key"""

    data = get_epds(search)
    parse_epd_list(data)


if __name__ == "__main__":
    search_epds({"name": "holz", "compliance": get_compliance_id("a2")})
